#ifndef __ICP_PLUGIN_H_
#define __ICP_PLUGIN_H_

// **********************************************
// To compile plugins (win32):
// 
// define PLUGIN_EXPORTS on the command line
//
// in Visual Studio:
// Project->Settings->C/C++, Category Preprocessor
// add PLUGIN_EXPORTS to 'preprocessor definitions'
// ***********************************************

#include "../../../Core/Interfaces/src/PluginInterface.h"

#include "icp_dialogimpl.h"

/**
 * This class implements a ICP plugin which computes
 * robust simultanous registration of point clouds.
 *
 * @author Christian Sigg
 * @version 0.1
 */
class ICP_Plugin : public PluginInterface {

public:
	
	PLUGIN_API ICP_Plugin();
	PLUGIN_API virtual ~ICP_Plugin();

	// *************************
	// interface PluginInterface
	// *************************

	PLUGIN_API void execute();
	PLUGIN_API bool isAvailable() const;

private:
	bool checkPluginAvailability() const;
};

// ****************
// access functions
// ****************

// extern "C" is needed so those functions can be accessed
// with GetProcAddress() (WIN32) and dlsym() (UNIX) respective
extern "C" {
	PLUGIN_API PluginInterface *createPlugin();
	PLUGIN_API const char *getPluginName();
	PLUGIN_API const char *getPluginDescription();
}

#endif  // __ICP_PLUGIN_H_

